"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ALLOW_JSX_UTILITY_CLASS = exports.ALLOW_COMPONENT_DID_CATCH = exports.COMPONENT_SHOULD_BE_FUNCTION = void 0;
exports.COMPONENT_SHOULD_BE_FUNCTION = "componentShouldBeFunction";
exports.ALLOW_COMPONENT_DID_CATCH = "allowComponentDidCatch";
exports.ALLOW_JSX_UTILITY_CLASS = "allowJsxUtilityClass";
const rule = {
    meta: {
        docs: {
            description: "Enforce components are written as function components",
            category: "Stylistic Issues",
            recommended: false,
            url: "https://github.com/tatethurston/eslint-plugin-react-prefer-function-component#rule-details",
        },
        type: "problem",
        messages: {
            [exports.COMPONENT_SHOULD_BE_FUNCTION]: "Class component should be written as a function",
        },
        schema: [
            {
                type: "object",
                properties: {
                    [exports.ALLOW_COMPONENT_DID_CATCH]: {
                        default: true,
                        type: "boolean",
                    },
                    [exports.ALLOW_JSX_UTILITY_CLASS]: {
                        default: false,
                        type: "boolean",
                    },
                },
                additionalProperties: false,
            },
        ],
    },
    create(context) {
        var _a, _b, _c;
        const options = (_a = context.options[0]) !== null && _a !== void 0 ? _a : {};
        const allowComponentDidCatch = (_b = options.allowComponentDidCatch) !== null && _b !== void 0 ? _b : true;
        const allowJsxUtilityClass = (_c = options.allowJsxUtilityClass) !== null && _c !== void 0 ? _c : false;
        function shouldPreferFunction(node) {
            const properties = node.body.body;
            const hasComponentDidCatch = properties.some((property) => {
                if ("key" in property && "name" in property.key) {
                    return property.key.name === "componentDidCatch";
                }
            });
            if (hasComponentDidCatch && allowComponentDidCatch) {
                return false;
            }
            return true;
        }
        const components = new Set();
        function detect(node) {
            if (shouldPreferFunction(node)) {
                components.add(node);
            }
        }
        function detectJsxInClass(node) {
            if (!allowJsxUtilityClass) {
                detect(node);
            }
        }
        return {
            "ClassDeclaration:has(JSXElement)": detectJsxInClass,
            "ClassDeclaration:has(JSXFragment)": detectJsxInClass,
            "ClassExpression:has(JSXElement)": detectJsxInClass,
            "ClassExpression:has(JSXFragment)": detectJsxInClass,
            "ClassDeclaration:has(JSXElement):has(MethodDefinition[key.name='render'])": detect,
            "ClassDeclaration:has(JSXFragment):has(MethodDefinition[key.name='render'])": detect,
            "ClassExpression:has(JSXElement):has(MethodDefinition[key.name='render'])": detect,
            "ClassExpression:has(JSXFragment):has(MethodDefinition[key.name='render'])": detect,
            "ClassDeclaration[superClass.object.name='React'][superClass.property.name='Component']": detect,
            "ClassDeclaration[superClass.object.name='React'][superClass.property.name='PureComponent']": detect,
            "ClassDeclaration[superClass.name='Component']": detect,
            "ClassDeclaration[superClass.name='PureComponent']": detect,
            "ClassExpression[superClass.object.name='React'][superClass.property.name='Component']": detect,
            "ClassExpression[superClass.object.name='React'][superClass.property.name='PureComponent']": detect,
            "ClassExpression[superClass.name='Component']": detect,
            "ClassExpression[superClass.name='PureComponent']": detect,
            "Program:exit": function () {
                components.forEach((component) => {
                    var _a;
                    switch (component.type) {
                        case "ClassDeclaration":
                        case "ClassExpression":
                            return context.report({
                                node: (_a = component.id) !== null && _a !== void 0 ? _a : component,
                                messageId: exports.COMPONENT_SHOULD_BE_FUNCTION,
                            });
                    }
                });
            },
        };
    },
};
exports.default = rule;
